@@ -10,6 +10,7 @@ from scipy.io import savemat
 import json
 import pandas as pd
 import csv
+from pyinspect import install_traceback
 
 from fcutils import path as fcpath
 from fcutils.plot.figure import save_figure
@@ -68,7 +69,8 @@ class Recorder:
     def start(
         self,
         base_folder: Union[str, Path] = None,
-        name: str = None,
+        folder_name: str = None,
+        logfile_name: str = None,
         timestamp: bool = True,
     ):
         self.started = utils.timestamp()
@@ -78,7 +80,7 @@ class Recorder:
         self.base_folder = (
             Path(base_folder) if base_folder is not None else Path("./cache")
         )
-        self.name = name or f"dpl_log"
+        self.name = folder_name or f"dpl_log"
 
         if timestamp:
             self.name += f"_{utils.timestamp()}"
@@ -102,10 +104,16 @@ class Recorder:
                 {"sink": RichHandler(markup=True), "format": "{message}"}
             ]
         )
-        log_file_path = self.folder / "log.log"
+        logfile_name = logfile_name or 'log'
+        log_file_path = self.folder / (logfile_name + ".log")
         if log_file_path.exists():
             log_file_path.unlink()
-        logger.add(log_file_path)
+
+        try:
+            logger.add(log_file_path)
+        except Exception:
+            log_file_path = self.folder / f"log_{utils.timestamp()}.log"
+            logger.add(log_file_path)
 
         logger.debug(f"DPL - Saving data and logs to {self.folder}")
         logger.debug(f"Saving log file to: {str(log_file_path)}")
@@ -126,7 +134,7 @@ class Recorder:
     @raise_if_not_started
     def add_data(
         self,
-        data: np.ndarray,
+        data: Union[dict, np.ndarray, pd.DataFrame, pd.Series],
         name: str,
         fmt: str = "npy",
         description: str = None,
@@ -160,6 +168,10 @@ class Recorder:
             # assumes the data are passed as a dict
             with open(dest, "w", encoding="utf-8") as f:
                 json.dump(data, f, ensure_ascii=False, indent=4)
+        elif fmt == "yaml":
+            # assumes the data are passed as a dict
+            with open(dest, "w", encoding="utf-8") as f:
+                yaml.dump(data, f, default_flow_style=False, indent=4)
         elif fmt == "csv":
             # assumes that data are a dict or pandas dataframe
             if isinstance(data, pd.DataFrame):
